pub struct DdlManager {
ddl_context: DdlContext,
procedure_manager: ProcedureManagerRef,
repartition_procedure_factory: RepartitionProcedureFactoryRef,
}Expand description
The DdlManager provides the ability to execute Ddl.
Fields
ddl_context: DdlContextprocedure_manager: ProcedureManagerRefrepartition_procedure_factory: RepartitionProcedureFactoryRefImplementations
Sourceimpl DdlManager
impl DdlManager
Sourcepub fn try_new(
ddl_context: DdlContext,
procedure_manager: ProcedureManagerRef,
repartition_procedure_factory: RepartitionProcedureFactoryRef,
register_loaders: bool,
) -> Result<Self>
pub fn try_new( ddl_context: DdlContext, procedure_manager: ProcedureManagerRef, repartition_procedure_factory: RepartitionProcedureFactoryRef, register_loaders: bool, ) -> Result<Self>
Returns a new DdlManager with all Ddl BoxedProcedureLoaders registered.
Sourcepub fn table_metadata_manager(&self) -> &TableMetadataManagerRef
pub fn table_metadata_manager(&self) -> &TableMetadataManagerRef
Returns the TableMetadataManagerRef.
Sourcepub fn create_context(&self) -> DdlContext
pub fn create_context(&self) -> DdlContext
Returns the DdlContext
Sourcepub fn register_loaders(&self) -> Result<()>
pub fn register_loaders(&self) -> Result<()>
Registers all Ddl loaders.
Sourceasync fn submit_repartition_task(
&self,
table_id: TableId,
table_name: TableName,
__arg3: Repartition,
wait: bool,
timeout: Duration,
) -> Result<(ProcedureId, Option<Output>)>
async fn submit_repartition_task( &self, table_id: TableId, table_name: TableName, __arg3: Repartition, wait: bool, timeout: Duration, ) -> Result<(ProcedureId, Option<Output>)>
Submits a repartition procedure for the specified table.
This creates a repartition procedure using the provided table_id,
table_name, and Repartition configuration, and then either executes it
to completion or just submits it for asynchronous execution.
The Repartition argument contains the original (from_partition_exprs)
and target (into_partition_exprs) partition expressions that define how
the table should be repartitioned.
The wait flag controls whether this method waits for the repartition
procedure to finish:
- If
waitistrue, the procedure is executed and this method awaits its completion, returning both the generatedProcedureIdand the finalOutputof the procedure. - If
waitisfalse, the procedure is only submitted to the procedure manager for asynchronous execution, and this method returns theProcedureIdalong withNoneas the output.
Sourcepub async fn submit_alter_table_task(
&self,
table_id: TableId,
alter_table_task: AlterTableTask,
ddl_options: DdlOptions,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_alter_table_task( &self, table_id: TableId, alter_table_task: AlterTableTask, ddl_options: DdlOptions, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes an alter table task.
Sourcepub async fn submit_create_table_task(
&self,
create_table_task: CreateTableTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_create_table_task( &self, create_table_task: CreateTableTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a create table task.
Sourcepub async fn submit_create_view_task(
&self,
create_view_task: CreateViewTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_create_view_task( &self, create_view_task: CreateViewTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a [CreateViewTask].
Sourcepub async fn submit_create_logical_table_tasks(
&self,
create_table_tasks: Vec<CreateTableTask>,
physical_table_id: TableId,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_create_logical_table_tasks( &self, create_table_tasks: Vec<CreateTableTask>, physical_table_id: TableId, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a create multiple logical table tasks.
Sourcepub async fn submit_alter_logical_table_tasks(
&self,
alter_table_tasks: Vec<AlterTableTask>,
physical_table_id: TableId,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_alter_logical_table_tasks( &self, alter_table_tasks: Vec<AlterTableTask>, physical_table_id: TableId, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes alter multiple table tasks.
Sourcepub async fn submit_drop_table_task(
&self,
drop_table_task: DropTableTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_drop_table_task( &self, drop_table_task: DropTableTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a drop table task.
Sourcepub async fn submit_create_database(
&self,
__arg1: CreateDatabaseTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_create_database( &self, __arg1: CreateDatabaseTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a create database task.
Sourcepub async fn submit_drop_database(
&self,
__arg1: DropDatabaseTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_drop_database( &self, __arg1: DropDatabaseTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a drop table task.
pub async fn submit_alter_database( &self, alter_database_task: AlterDatabaseTask, ) -> Result<(ProcedureId, Option<Output>)>
Sourcepub async fn submit_create_flow_task(
&self,
create_flow: CreateFlowTask,
query_context: QueryContext,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_create_flow_task( &self, create_flow: CreateFlowTask, query_context: QueryContext, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a create flow task.
Sourcepub async fn submit_drop_flow_task(
&self,
drop_flow: DropFlowTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_drop_flow_task( &self, drop_flow: DropFlowTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a drop flow task.
Sourcepub async fn submit_drop_view_task(
&self,
drop_view: DropViewTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_drop_view_task( &self, drop_view: DropViewTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a drop view task.
Sourcepub async fn submit_truncate_table_task(
&self,
truncate_table_task: TruncateTableTask,
table_info_value: DeserializedValueWithBytes<TableInfoValue>,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_truncate_table_task( &self, truncate_table_task: TruncateTableTask, table_info_value: DeserializedValueWithBytes<TableInfoValue>, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a truncate table task.
Sourcepub async fn submit_comment_on_task(
&self,
comment_on_task: CommentOnTask,
) -> Result<(ProcedureId, Option<Output>)>
pub async fn submit_comment_on_task( &self, comment_on_task: CommentOnTask, ) -> Result<(ProcedureId, Option<Output>)>
Submits and executes a comment on task.
Sourceasync fn execute_procedure_and_wait(
&self,
procedure_with_id: ProcedureWithId,
) -> Result<(ProcedureId, Option<Output>)>
async fn execute_procedure_and_wait( &self, procedure_with_id: ProcedureWithId, ) -> Result<(ProcedureId, Option<Output>)>
Executes a procedure and waits for the result.
Sourceasync fn submit_procedure(
&self,
procedure_with_id: ProcedureWithId,
) -> Result<ProcedureId>
async fn submit_procedure( &self, procedure_with_id: ProcedureWithId, ) -> Result<ProcedureId>
Submits a procedure and returns the procedure id.
pub async fn submit_ddl_task( &self, ctx: &ExecutorContext, request: SubmitDdlTaskRequest, ) -> Result<SubmitDdlTaskResponse>